@@ -1,15 +1,12 @@
 #!/bin/bash
 set -e
 
-# The python:3.11-slim container doesn't have git, which flit needs to build the package.
 echo "Installing git..."
 apt-get update -y && apt-get install -y git --no-install-recommends
 
-# Ensure python dependencies are installed first
 pip install requests --quiet
 
-# Read version directly from pyproject.toml
-PACKAGE_NAME="kaggle-environments" # Define package name for reuse
+PACKAGE_NAME="kaggle-environments"
 VERSION_FROM_PYPROJECT=$(grep -E "^version\s*=\s*\"[0-9]+\.[0-9]+\.[0-9]+\"$" pyproject.toml | cut -d '"' -f 2)
 CLOUD_RUN_REQS_PATH="docker/cloud-run-source/requirements.txt"
 
@@ -20,7 +17,6 @@ fi
 
 echo "Found version $VERSION_FROM_PYPROJECT in pyproject.toml. Checking against PyPI."
 
-# (Your Python script to check for existing version remains the same)
 cat > /tmp/check_pypi.py << EOL
 import sys
 import requests
@@ -52,6 +48,7 @@ else
 
   flit publish
   
+  # It takes a bit for the package to show up on PyPI. Make sure it's visible through Pip before proceeding.
   # --- RETRY LOGIC START ---
   echo "Verifying that package '$PACKAGE_NAME==$VERSION_FROM_PYPROJECT' is available from PyPI..."
   MAX_RETRIES=10
@@ -60,7 +57,6 @@ else
 
   for i in $(seq 1 $MAX_RETRIES)
   do
-    # Use 'pip install' with --no-cache-dir as the check. This is the most reliable method.
     if python -m pip install --no-cache-dir "$PACKAGE_NAME==$VERSION_FROM_PYPROJECT" --quiet; then
       echo "✅ Successfully found and installed package from PyPI."
       SUCCESS=true
@@ -75,11 +71,14 @@ else
     echo "❌ Failed to find package on PyPI after $MAX_RETRIES attempts. Aborting."
     exit 1
   fi
+  # --- SAFETY BUFFER ---
+  # The package is available, but let's wait a bit longer for CDN propagation.
+  echo "Waiting 45 seconds as a safety buffer for CDN propagation..."
+  sleep 45
   # --- RETRY LOGIC END ---
 
   echo "Successfully published and verified. Updating Cloud Run requirements at $CLOUD_RUN_REQS_PATH..."
   
-  # Use sed to replace the placeholder with the actual version
   sed -i "s/VERSION_FROM_CICD_DEPLOY/${VERSION_FROM_PYPROJECT}/" "$CLOUD_RUN_REQS_PATH"
   
   echo "Cloud Run requirements.txt updated."
